@@ -8,11 +8,11 @@
 #
 ################################################################################
 #
-# $Project: Convert-Binary-C $
+# $Project: /Convert-Binary-C $
 # $Author: mhx $
-# $Date: 2003/01/14 21:11:24 +0100 $
-# $Revision: 35 $
-# $Snapshot: /Convert-Binary-C/0.10 $
+# $Date: 2003/02/24 08:21:27 +0100 $
+# $Revision: 37 $
+# $Snapshot: /Convert-Binary-C/0.11 $
 # $Source: /lib/Convert/Binary/C.pm $
 #
 ################################################################################
@@ -32,10 +32,10 @@ use vars qw( @ISA $VERSION $XS_VERSION $AUTOLOAD );
 
 @ISA = qw(DynaLoader);
 
-$VERSION    = sprintf '%.2f', 0.01*('$Revision: 35 $' =~ /(\d+)/)[0];
-$XS_VERSION =  do { my @r = '$Snapshot: /Convert-Binary-C/0.10 $'
+$VERSION    = sprintf '%.2f', 0.01*('$Revision: 37 $' =~ /(\d+)/)[0];
+$XS_VERSION =  do { my @r = '$Snapshot: /Convert-Binary-C/0.11 $'
                             =~ /(\d+\.\d+(?:_\d+)?)/;
-                    @r ? $r[0] : '9.99' },
+                    @r ? $r[0] : '9.99' };
 
 bootstrap Convert::Binary::C $XS_VERSION;
 
@@ -2867,6 +2867,11 @@ joy and last but not least for proofreading the documentation.
 
 =item *
 
+Alain Barbet E<lt>alian@cpan.orgE<gt> for testing and debugging
+support.
+
+=item *
+
 Michael J. Hohmann E<lt>mjh@scientist.deE<gt> for endless discussions
 on our way to and back home from work, and for making me think
 about supporting L<C<pack>|/"pack"> and L<C<unpack>|/"unpack"> for
